@@ -2,11 +2,13 @@ from __future__ import annotations
 
 import argparse
 import builtins
+import json
 import logging
 import os
 import shlex
 import subprocess as sp
 import sys
+import textwrap
 import uuid
 from functools import partial
 from pathlib import Path
@@ -171,11 +173,17 @@ class BuildAwareCommand(Command):
                             "         %s command."
                             % (
                                 colored(str(lockfile_path), attrs=["bold"]),
-                                colored("kraken env lock", "grey", attrs=["underline"]),
+                                colored("kraken env lock", "cyan", attrs=["underline"]),
                             ),
                             "yellow",
                         )
                     )
+                    prefix = "         "
+                    print()
+                    print(prefix + colored("Requirements in lockfile:", "yellow"))
+                    print(textwrap.indent(json.dumps(lockfile.requirements.to_json(), indent=2), prefix + "  "))
+                    print(prefix + colored("Requirements in project:", "yellow"))
+                    print(textwrap.indent(json.dumps(requirements.to_json(), indent=2), prefix + "  "))
 
                 return
 
